@@ -42,6 +42,10 @@ except ImportError:
     pass
 
 
+__version__ = "1.19.11"
+__repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_DisplayIO_Layout.git"
+
+
 class Cartesian(Widget):
     """A cartesian widget.  The origin is set using ``x`` and ``y``.
 
